<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="vi_VN">
<context>
    <name>ClipGrab</name>
    <message>
        <location filename="clipgrab.cpp" line="36"/>
        <source>Automatic language recognition</source>
        <translation>Tự động nhận diện ngôn ngữ</translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="512"/>
        <source>Downloading update … %1/%2 MBytes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="521"/>
        <source>There was an error while downloading the update.: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="535"/>
        <source>The fingerprint of the downloaded update file could not be verified: %1 should have been %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="547"/>
        <source>Could not open update file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="585"/>
        <source>Unable to write to %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="607"/>
        <source>SSL error: %1 
%2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="614"/>
        <source>Error downloading youtube-dl: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="805"/>
        <source>B</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="805"/>
        <source>KiB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="805"/>
        <source>MiB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="805"/>
        <source>GiB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="805"/>
        <source>TiB</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DownloadListModel</name>
    <message>
        <location filename="download_list_model.cpp" line="99"/>
        <source>Starting ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="download_list_model.cpp" line="106"/>
        <source>Converting ...</source>
        <translation type="unfinished">Đang chuyển đổi ...</translation>
    </message>
    <message>
        <location filename="download_list_model.cpp" line="108"/>
        <source>Finished</source>
        <translation type="unfinished">Xong</translation>
    </message>
    <message>
        <location filename="download_list_model.cpp" line="110"/>
        <source>Paused</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="download_list_model.cpp" line="112"/>
        <source>Canceled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="download_list_model.cpp" line="114"/>
        <source>Waiting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="download_list_model.cpp" line="116"/>
        <source>Failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="download_list_model.h" line="37"/>
        <source>Portal</source>
        <translation type="unfinished">Cổng</translation>
    </message>
    <message>
        <location filename="download_list_model.h" line="37"/>
        <source>Title</source>
        <translation type="unfinished">Tiêu đề</translation>
    </message>
    <message>
        <location filename="download_list_model.h" line="37"/>
        <source>Quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="download_list_model.h" line="37"/>
        <source>Format</source>
        <translation type="unfinished">Định dạng</translation>
    </message>
    <message>
        <location filename="download_list_model.h" line="37"/>
        <source>Progress</source>
        <translation type="unfinished">Tiến trình</translation>
    </message>
</context>
<context>
    <name>HelperDownloader</name>
    <message>
        <location filename="helper_downloader.ui" line="14"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="helper_downloader.ui" line="20"/>
        <source>Continue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="helper_downloader.ui" line="27"/>
        <source>Exit ClipGrab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="helper_downloader.ui" line="85"/>
        <source>&lt;p&gt;ClipGrab uses youtube-dl in order to download videos from the Internet. youtube-dl is developed by an independent team of Open Source developers and released into the public domain.&lt;br&gt;Learn more on &lt;a href=&quot;https://youtube-dl.org&quot;&gt;youtube-dl.org&lt;/a&gt;.&lt;/p&gt;&lt;p&gt;Click on &lt;em&gt;Continue&lt;/em&gt; to download youtube-dl.&lt;/p&gt;</source>
        <oldsource>&lt;p&gt;ClipGrab uses youtube-dl in order to download videos from the Internet. youtube-dl is developed by an independent team of Open Source developers and released into the public domain.&lt;br&gt;Learn more on &lt;a href=&quot;https://youtube-dl.org&quot;&gt;youtube-dl.org&lt;/a&gt;.&lt;/p&gt;&lt;p&gt;Click on &lt;em&gt;Continue&lt;/em&gt; to automatically download youtube-dl.&lt;/p&gt;</oldsource>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="helper_downloader.ui" line="99"/>
        <source>Downloading youtube-dl</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.cpp" line="273"/>
        <source>Select Target</source>
        <translatorcomment>Chọn nơi lưu và đặt tên cho File</translatorcomment>
        <translation>Chọn nơi lưu file</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="74"/>
        <source>Please wait while ClipGrab is loading information about the video ...</source>
        <translation>Vui lòng đợi ClipGrab lấy thông tin về video ...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="327"/>
        <source>Please enter the link to the video you want to download in the field below.</source>
        <translation>Nhập link video muốn tải về vào ô trống bên dưới.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="333"/>
        <source>No downloadable video could be found.&lt;br /&gt;Maybe you have entered the wrong link or there is a problem with your connection.</source>
        <translation>Không có video nào có thể tải được.&lt;br/&gt;Có thể bạn vừa nhập sai link hoặc kết nối của bạn có vấn đề.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="376"/>
        <source>ClipGrab - Select target path</source>
        <translation>ClipGrab - Chọn đường dẫn</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="415"/>
        <source>ClipGrab: Video discovered in your clipboard</source>
        <translation>ClipGrab: Video vừa được sao chép vào bộ nhớ đệm</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="415"/>
        <source>ClipGrab has discovered the address of a compatible video in your clipboard. Click on this message to download it now.</source>
        <translation>ClipGrab vừa phát hiện địa chỉ của một video phù hợp trong bộ nhớ đệm. Bấm vào thông báo này để tải ngay.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="499"/>
        <source>ClipGrab - Exit confirmation</source>
        <translation>ClipGrab - Xác nhận thoát</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="499"/>
        <source>There is still at least one download in progress.&lt;br /&gt;If you exit the program now, all downloads will be canceled and cannot be recovered later.&lt;br /&gt;Do you really want to quit ClipGrab now?</source>
        <translation>Vẫn còn ít nhất một video đang tải.&lt;br/&gt;Nếu thoát bây giờ, tất cả video đang và chưa tải sẽ bị hủy, và không thể khôi phục được.&lt;br/&gt;Bạn thật sự muốn thoát ClipGrab?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="527"/>
        <source>Download finished</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="527"/>
        <source>Downloading and converting “%title” is now finished.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="529"/>
        <source>All downloads finished</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="529"/>
        <source>ClipGrab has finished downloading and converting all selected videos.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="683"/>
        <source>No results found.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="740"/>
        <source>&amp;Open downloaded file</source>
        <translation>&amp;Mở file đã tải về</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="741"/>
        <source>Open &amp;target folder</source>
        <translation>Mở &amp;thư mục chứa video</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="743"/>
        <source>&amp;Pause download</source>
        <translation>Tạm &amp;dừng tải về</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="744"/>
        <source>&amp;Restart download</source>
        <translation>&amp;Bắt đầu tải lại</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="745"/>
        <source>&amp;Cancel download</source>
        <translation>&amp;Hủy tải về</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="747"/>
        <source>Copy &amp;video link</source>
        <translation>Sao chép liên kết &amp;video</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="748"/>
        <source>Open video link in &amp;browser</source>
        <translation>Mở liên &amp;kết trong trình duyệt</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="751"/>
        <source>Resume download</source>
        <translation>Tiếp tục tải về</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="764"/>
        <source>Show in &amp;Finder</source>
        <translation>Hiển thị trong trình &amp;tìm kiếm</translation>
    </message>
</context>
<context>
    <name>MainWindowClass</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <source>ClipGrab - Download and Convert Online Videos</source>
        <translation>ClipGrab - Tải và chuyển đổi Videos</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="153"/>
        <source>Search</source>
        <translation>Tìm kiếm</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="172"/>
        <source>Enter keywords in the box below in order to search videos on YouTube</source>
        <translation>Nhập từ khóa vào bên dưới để tìm video trên YouTube</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="190"/>
        <source>Downloads</source>
        <translation>Tải về</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="199"/>
        <source>Grab this clip!</source>
        <translation>Tải clip này!</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="234"/>
        <source>Quality:</source>
        <translation>Chất lượng:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="250"/>
        <source>Please enter the link to the video you want to download in the field below.</source>
        <translation>Nhập liên kết tới video bạn muốn tải về vào ô bên dưới.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="291"/>
        <source>Format:</source>
        <translation>Định dạng:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="343"/>
        <source>Current Downloads:</source>
        <translation>Đang tải:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="363"/>
        <source>Cancel selected download</source>
        <translation>Hủy bỏ mục đang chọn</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="353"/>
        <source>Open the target folder of the selected download</source>
        <translation>Mở thư mục chứa của mục đang chọn</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="373"/>
        <source>Pause selected download</source>
        <translation>Tạm dừng mục đang chọn</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="385"/>
        <source>Settings</source>
        <translation>Thiết lập</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="398"/>
        <source>General</source>
        <translation>Chung</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="422"/>
        <source>Here you can adjust some general settings concerning the behaviour of ClipGrab.</source>
        <translation>Ở đây bạn có thể điều chỉnh một số thiết lập chung liên quan đến cách hoạt động của ClipGrab.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="433"/>
        <source>Target Path</source>
        <translation>Đường dẫn đích</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="439"/>
        <source>Always save at the last used path.</source>
        <translation>Luôn lưu tại đường dẫn gần đây nhất.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="453"/>
        <source>Here you can configure where the downloaded videos are to be saved.</source>
        <translation>Ở đây bạn có thể cấu hình nơi lưu video tải về.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="460"/>
        <source>Browse ...</source>
        <translation>Duyệt ...</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="467"/>
        <source>Never ask for file name</source>
        <translation>Không hỏi tên file</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="488"/>
        <source>Metadata</source>
        <translation>Metadata</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="494"/>
        <source>Here you can configure if ClipGrab is supposed to add metadata (ID3 tags) to your mp3 files.</source>
        <translation>Ở đây bạn có thể cấu hình ClipGrab để thêm metada (ID3 tags) vào file Mp3.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="501"/>
        <source>Use metadata</source>
        <translation>Dùng Metadata</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="522"/>
        <source>Clipboard</source>
        <translation>Bộ nhớ đệm</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="528"/>
        <source>Here you can configure how ClipGrab behaves when a downloadable video is discovered in your clipboard.</source>
        <translation>Ở đây bạn có thể cấu hình ClipGrab hành động  như thế nào khi phát hiện liên kết video trong bộ nhớ đệm.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="535"/>
        <source>Always download</source>
        <translation>Luôn luôn tải về</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="542"/>
        <source>Never download</source>
        <translation>Không tải về</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="549"/>
        <source>Always ask</source>
        <translation>Luôn luôn hỏi</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="570"/>
        <source>Notifications</source>
        <translation>Thông báo</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="576"/>
        <source>After each download</source>
        <translation>Sau khi kết thúc mỗi tải về</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="583"/>
        <source>After all downloads have been completed</source>
        <translation>Sau khi tất cả tải về hoàn tất</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="603"/>
        <source>Here you can configure when ClipGrab is supposed to display notifications.</source>
        <translation>Ở đây bạn có thể cấu hình khi nào ClipGrab phải hiển thị các thông báo.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="610"/>
        <source>Never</source>
        <translation>Không bao giờ</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="618"/>
        <source>Proxy</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="624"/>
        <source>Use a proxy server</source>
        <translation>Dùng máy chủ proxy</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="634"/>
        <source>Proxy settings</source>
        <translation>Tùy chỉnh Proxy</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="643"/>
        <source>Hostname/IP:</source>
        <translation>Tên máy chủ/IP:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="650"/>
        <source>Port:</source>
        <translation>Cổng:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="677"/>
        <source>Proxy type:</source>
        <translation>Kiểu proxy:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="685"/>
        <source>HTTP Proxy</source>
        <translation>HTTP Proxy</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="690"/>
        <source>Socks5 Proxy</source>
        <translation>Socks5 Proxy</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="717"/>
        <source>Proxy authentication</source>
        <translation>Chứng thực proxy</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="723"/>
        <source>Username:</source>
        <translation>Tên tài khoản:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="740"/>
        <source>Password:</source>
        <translation>Mật khẩu:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="753"/>
        <source>Proxy requires authentication</source>
        <translation>Proxy yêu cầu chứng thực</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="761"/>
        <source>Other</source>
        <translation>Khác</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="788"/>
        <source>Remove finished downloads from list</source>
        <translation>Xóa video đã tải xong khỏi danh sách</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1182"/>
        <source>&lt;h2&gt;Thanks&lt;/h2&gt;
ClipGrab relies on the work of the Qt project, the ffmpeg team, and the youtube-dl team.&lt;br&gt;
Visit &lt;a href=&quot;https://www.qt.io&quot;&gt;qt.io&lt;/a&gt;, &lt;a href=&quot;https://ffmpeg.org&quot;&gt;ffmpeg.org&lt;/a&gt;, and &lt;a href=&quot;https://youtube-dl.org&quot;&gt;youtube-dl.org&lt;/a&gt; for further information.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="767"/>
        <source>Minimize ClipGrab to the system tray</source>
        <translation>Ẩn ClipGrab xuống khay hệ thống</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="774"/>
        <source>Use WebM if possible</source>
        <translation>Sử dụng WebM khi có thể</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="781"/>
        <source>Ignore SSL errors</source>
        <translation>Bỏ qua lỗi SSL</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="808"/>
        <source>Remember logins</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="815"/>
        <source>Remember video quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="827"/>
        <source>Language</source>
        <translation>Ngôn ngữ</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="851"/>
        <source>Here you can change the language of ClipGrab.</source>
        <translation>Ở đây bạn có thể thay đổi ngôn ngữ hiển thị cho ClipGrab.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="858"/>
        <source>Please select a language from the list below. You have to restart ClipGrab in order to apply you selection.</source>
        <translation>Vui lòng chọn một ngôn ngữ ở danh sách bên dưới. Bạn phải chạy lại ClipGrab để thay đổi có hiệu lực.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="895"/>
        <source>Conversion</source>
        <translation>Chuyển đổi</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="918"/>
        <source>Experts can create custom presets for the video conversion here.</source>
        <translation>Những  người thông thạo có thể tạo những Thiết đặt sẵn cho việc chuyển đổi video ở đây.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="925"/>
        <source>Format preset</source>
        <translation>Định dạng cài sẵn</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="935"/>
        <source>Add new preset</source>
        <translation>Thêm cài sẵn mới</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="942"/>
        <source>Remove selected preset</source>
        <translation>Xóa cài sẵn đang chọn</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="965"/>
        <source>Audio</source>
        <translation>Âm thanh</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="977"/>
        <location filename="mainwindow.ui" line="1029"/>
        <source>Codec</source>
        <translation>Mã hóa</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1003"/>
        <location filename="mainwindow.ui" line="1091"/>
        <source>Bitrate (kb/s)</source>
        <translation>Bitrate (kb/s)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1010"/>
        <source>Disable Audio</source>
        <translation>Xóa bỏ âm thanh</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1020"/>
        <source>Video</source>
        <translation>Hình ảnh</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1042"/>
        <source>Frames/second</source>
        <translation>Khung hình/giây</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1101"/>
        <source>Disable video</source>
        <translation>Xóa bỏ hình ảnh</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1116"/>
        <source>About</source>
        <translation>Giới thiệu</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1122"/>
        <source>&lt;h2&gt;Support ClipGrab!&lt;/h2&gt;
&lt;p&gt;Only with your support, ClipGrab can remain free software!&lt;br&gt;So if you like ClipGrab and also want to help ensuring its further development, please consider making a donation.&lt;/p&gt;</source>
        <translation>&lt;h2&gt;Hỗ trợ ClipGrab!&lt;/h2&gt;
&lt;p&gt;Với sự hỗ trợ của bạn, ClipGrab có thể giữ nguyên là phần mềm miễn phí!&lt;br&gt;Nên nếu bạn thích ClipGrab và muốn giúp đảm bảo sự phát triển trong tương lai,bạn có thể ủng hộ chúng tôi.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1165"/>
        <source>&lt;h2&gt;Translation&lt;/h2&gt;
ClipGrab is already available in many languages. If ClipGrab has not been translated into your language yet and if you want to contribute a translation, please check &lt;a href=&quot;http://clipgrab.de/translate&quot;&gt;http://clipgrab.de/translate&lt;/a&gt; for further information.</source>
        <translation>&lt;h2&gt;Dịch thuật&lt;/h2&gt;
Bản dịch sang tiếng Việt được thực hiện bởi Peter &quot;Darkraise&quot; Trình, &lt;a href=&quot;https://facebook.com/Petros.Darkraise&quot;&gt;facebook&lt;/a&gt;. Email:&lt;a href=&quot;mailto:senelupin15@gmail.com&quot;&gt;senelupin15@gmail.com&lt;/a&gt;.</translation>
    </message>
</context>
<context>
    <name>MetadataDialog</name>
    <message>
        <location filename="metadata-dialog.ui" line="14"/>
        <source>ClipGrab - enter metadata</source>
        <translation>ClipGrab - nhập metadate</translation>
    </message>
    <message>
        <location filename="metadata-dialog.ui" line="25"/>
        <source>Please enter the metadata for your download. If you don&apos;t want to add metadata, just leave the fields empty.</source>
        <translation>Vui lòng nhập metadata cho file của bạn. Nếu bạn không muốn thêm metadata, chỉ cần để trống các ô.</translation>
    </message>
    <message>
        <location filename="metadata-dialog.ui" line="45"/>
        <source>Title:</source>
        <translation>Tiêu đề:</translation>
    </message>
    <message>
        <location filename="metadata-dialog.ui" line="52"/>
        <source>Artist:</source>
        <translation>Nghệ sĩ:</translation>
    </message>
</context>
<context>
    <name>UpdateMessage</name>
    <message>
        <location filename="update_message.ui" line="14"/>
        <source>Update for ClipGrab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="update_message.ui" line="116"/>
        <source>ClipGrab %1 is now available (you are using %2). Would you like to install the update?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="update_message.ui" line="130"/>
        <source>There is an update for your version of ClipGrab!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="update_message.ui" line="64"/>
        <source>Skip this update</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="update_message.ui" line="91"/>
        <source>Download update</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="update_message.ui" line="240"/>
        <source>about:blank</source>
        <translation type="unfinished">about:blank</translation>
    </message>
    <message>
        <location filename="update_message.ui" line="74"/>
        <source>Remind me later</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="update_message.ui" line="41"/>
        <source>The update will begin in just a moment …</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>converter_copy</name>
    <message>
        <location filename="converter_copy.cpp" line="28"/>
        <source>Original</source>
        <translation>Gốc</translation>
    </message>
</context>
<context>
    <name>converter_ffmpeg</name>
    <message>
        <location filename="converter_ffmpeg.cpp" line="216"/>
        <source>MPEG4</source>
        <translation>MPEG4</translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="217"/>
        <source>WMV (Windows)</source>
        <translation>WMV (Windows)</translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="218"/>
        <source>OGG Theora</source>
        <translation>OGG Theora</translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="219"/>
        <source>MP3 (audio only)</source>
        <translation>MP3 (chỉ có tiếng)</translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="220"/>
        <source>OGG Vorbis (audio only)</source>
        <translation>OGG Vorbis (chỉ có tiếng)</translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="221"/>
        <source>Original (audio only)</source>
        <translation>Nguyên gốc (chỉ có tiếng)</translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="356"/>
        <source>No installed version of avconv or ffmpeg coud be found. Converting files and downloading 1080p videos from YouTube is not supported.</source>
        <translation>Không tìm thấy phiên bản sẵn có nào của avconv hay ffmpeg. Chuyển đổi định dạng và tải full HD 1080p từ YouTube sẽ không được hỗ trợ.</translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="371"/>
        <source>The installed version of %1 is outdated.
Downloading 1080p videos from YouTube is not supported.</source>
        <translation>Phiên bản được cài đặt của %1 đã lỗi thời.
Tải video 1080p từ YouTube sẽ không được hỗ trợ.</translation>
    </message>
</context>
<context>
    <name>messageDialog</name>
    <message>
        <location filename="message_dialog.ui" line="14"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="message_dialog.ui" line="48"/>
        <source>Close this message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="message_dialog.ui" line="71"/>
        <source>about:blank</source>
        <translation type="unfinished">about:blank</translation>
    </message>
</context>
<context>
    <name>video</name>
    <message>
        <location filename="video.cpp" line="261"/>
        <source>unknown</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
